msg_plat/conversation_services_utilities_api/inc/ccsclientconversation.h
changeset 25 84d9eb65b26f
parent 23 238255e8b033
child 47 5b14749788d7
--- a/msg_plat/conversation_services_utilities_api/inc/ccsclientconversation.h	Fri Apr 16 14:56:15 2010 +0300
+++ b/msg_plat/conversation_services_utilities_api/inc/ccsclientconversation.h	Mon May 03 12:29:07 2010 +0300
@@ -76,57 +76,23 @@
             TCsConversationEntryID aEnryId);
 
     /**
      * GetFirstName
      * Provides the Conversation first name of this object
      *
      * @return Instance of Conversation first name of this object
      */
-    IMPORT_C HBufC* GetFirstName() const;
-
-    /**
-     * SetFirstNameL
-     * Sets the Conversation first name of this object
-     *  
-     * @param aFirstName Instance of Conversation first name
-     */
-    IMPORT_C void SetFirstNameL(
-            const HBufC* aFirstName);
-
-    /**
-     * GetLastName
-     * Provides the Conversation last name of this object
-     *
-     * @return Instance of Conversation last name of this object
-     */
-    IMPORT_C HBufC* GetLastName() const;
+    IMPORT_C HBufC* GetDisplayName() const;
 
     /**
      * SetLastNameL
      * Sets the Conversation last name of this object
      *  
      * @param aLastName Instance of Conversation last name
      */
-    IMPORT_C void SetLastNameL(
-            const HBufC* aLastName);
+    IMPORT_C void SetDisplayNameL(
+            const HBufC* aDisplayName);
 
     /**
-     * GetNickName
-     * Provides the Conversation nick name of this object
-     *
-     * @return Instance of Conversation nick name of this object
-     */
-    IMPORT_C HBufC* GetNickName() const;
-    
-    /**
-     * SetNickNameL
-     * Sets the Conversation nick name of this object
-     *  
-     * @param aNickName Instance of Conversation nick name
-     */
-    IMPORT_C void SetNickNameL(
-            const HBufC* aNickName);
-    
-    /**
      * GetContactId
      * Provides the Contact Id for the conversation
      *
@@ -277,22 +243,10 @@
     TCsConversationEntryID iConversationEntryID;
 
     /**
      * iFirstName
      * First name of conversation
      */
-    HBufC*  iFirstName;
-
-    /**
-     * iLastName
-     * Last name of conversation
-     */
-    HBufC*  iLastName;
-    
-    /**
-     * iNickName
-     * Last name of conversation
-     */
-    HBufC*  iNickName;
+    HBufC*  iDisplayName;
 
     /**
      * iContactId
@@ -76,57 +76,23 @@
 
     /**
-     * GetFirstName
-     * Provides the Conversation first name of this object
+     * GetDisplayName
+     * Provides the Conversation display name of this object
      *
@@ -76,57 +76,23 @@
      *
-     * @return Instance of Conversation first name of this object
+     * @return Instance of Conversation display name of this object
      */
@@ -76,57 +76,23 @@
 
     /**
-     * SetLastNameL
-     * Sets the Conversation last name of this object
+     * SetDisplayNameL
+     * Sets the Conversation display name of this object
      *  
@@ -76,57 +76,23 @@
      *  
-     * @param aLastName Instance of Conversation last name
+     * @param aDisplayName Instance of Conversation display name
      */
@@ -277,22 +243,10 @@
 
     /**
-     * iFirstName
-     * First name of conversation
+     * iDisplayName
+     * Display name of conversation
      */